@@ -7,7 +7,7 @@ from .core import (
     interact,
 )
 from .deco import PteraDecorator, tooled
-from .probe import Probe, probing
+from .probe import LocalProbe, Probe, accumulate, probing
 from .recur import Recurrence
 from .selector import select
 from .selfless import ConflictError, Override, default, override, transform
