@@ -242,7 +242,7 @@ parser = opparse.Parser(
         {
             # r"\s*(?:\bas\b|>>|!+|\[\[|\]\]|[(){}\[\]>:,$=~])?\s*": "OPERATOR",
             r"\s*(?:\bas\b|>>|!+|\[\[|\]\]|[(){}\[\]>:,$=~])\s*|\s+": "OPERATOR",
-            r"[a-zA-Z_0-9#@*.-]+": "WORD",
+            r"[a-zA-Z_0-9#@*./-]+": "WORD",
             r"'[^']*'": "STRING",
         }
     ),
